[![Build Status](https://travis-ci.org/wmshort/sanskritwordnet.svg?branch=master)](https://travis-ci.org/wmshort/sanskritwordnet)

Sanskrit WordNet API
=====================

This module provides a light-weight wrapper for the Sanskrit WordNet API.
